/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010-2012 University of Bonn. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * TextDialog.cpp
 *
 *  Created on: Jan 5, 2010
 *      Author: crueger
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "TextUI/TextDialog.hpp"
#include "TextUI/Query/TextQuery.hpp"

using namespace std;


TextDialog::TextDialog(const std::string &_title) :
        Dialog(_title)
{
}

TextDialog::~TextDialog()
{
}

void TextDialog::queryEmpty(const std::string title, const std::string description){
  registerQuery(new EmptyTextQuery(title,description));
}

void TextDialog::queryBoolean(Parameter<bool> &_param, const std::string title, const std::string description){
  registerQuery(new BooleanTextQuery(_param, title,description));
}

void TextDialog::queryInt(Parameter<int> &_param, const std::string title, const std::string description){
  registerQuery(new IntTextQuery(_param, title,description));
}

void TextDialog::queryInts(Parameter<std::vector<int> > &_param, const std::string title, const std::string description){
  registerQuery(new IntsTextQuery(_param, title,description));
}

void TextDialog::queryUnsignedInt(Parameter<unsigned int> &_param, const std::string title, const std::string description){
  registerQuery(new UnsignedIntTextQuery(_param, title,description));
}

void TextDialog::queryUnsignedInts(Parameter<std::vector<unsigned int> > &_param, const std::string title, const std::string description){
  registerQuery(new UnsignedIntsTextQuery(_param, title,description));
}

void TextDialog::queryDouble(Parameter<double> &_param, const std::string title, const std::string description){
  registerQuery(new DoubleTextQuery(_param, title,description));
}

void TextDialog::queryDoubles(Parameter<std::vector<double> > &_param, const std::string title, const std::string description){
  registerQuery(new DoublesTextQuery(_param, title,description));
}

void TextDialog::queryString(Parameter<std::string> &_param, const std::string title, const std::string description){
  registerQuery(new StringTextQuery(_param, title,description));
}

void TextDialog::queryStrings(Parameter<std::vector<std::string> > &_param, const std::string title, const std::string description){
  registerQuery(new StringsTextQuery(_param, title,description));
}

void TextDialog::queryAtom(Parameter<const atom *> &_param, const std::string title, const std::string description) {
  registerQuery(new AtomTextQuery(_param, title,description));
}

void TextDialog::queryAtoms(Parameter<std::vector<const atom *> > &_param, const std::string title, const std::string description) {
  registerQuery(new AtomsTextQuery(_param, title,description));
}

void TextDialog::queryMolecule(Parameter<const molecule *> &_param, const std::string title, const std::string description) {
  registerQuery(new MoleculeTextQuery(_param, title,description));
}

void TextDialog::queryMolecules(Parameter<std::vector<const molecule *> > &_param, const std::string title, const std::string description) {
  registerQuery(new MoleculesTextQuery(_param, title,description));
}

void TextDialog::queryVector(Parameter<Vector> &_param, const std::string title, const std::string description) {
  registerQuery(new VectorTextQuery(_param, title,description));
}

void TextDialog::queryVectors(Parameter<std::vector<Vector> > &_param, const std::string title, const std::string description) {
  registerQuery(new VectorsTextQuery(_param, title,description));
}

void TextDialog::queryRealSpaceMatrix(Parameter<RealSpaceMatrix> &_param, const std::string title, const std::string description) {
  registerQuery(new RealSpaceMatrixTextQuery(_param, title,description));
}

void TextDialog::queryElement(Parameter<const element *> &_param, const std::string title, const std::string description){
  registerQuery(new ElementTextQuery(_param, title,description));
}

void TextDialog::queryElements(Parameter<std::vector<const element *> > &_param, const std::string title, const std::string description){
  registerQuery(new ElementsTextQuery(_param, title,description));
}

void TextDialog::queryFile(Parameter<boost::filesystem::path> &_param, const std::string title, const std::string description){
  registerQuery(new FileTextQuery(_param, title,description));
}

void TextDialog::queryFiles(Parameter<std::vector< boost::filesystem::path> > &_param, const std::string title, const std::string description){
  registerQuery(new FilesTextQuery(_param, title,description));
}

void TextDialog::queryRandomNumberDistribution_Parameters(Parameter<RandomNumberDistribution_Parameters> &_param, const std::string title, const std::string description){
  registerQuery(new RandomNumberDistribution_ParametersTextQuery(_param, title,description));
}


/************************** Query Infrastructure ************************/
/*       ---> shifted to folder Query                                   */
/************************************************************************/

